package com.ruoyi.project.business.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.project.business.domain.TcLeadHistory;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author ruoyi
 * @date 2024-04-22
 */
public interface ITcLeadHistoryService extends IService<TcLeadHistory>
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param leadId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TcLeadHistory selectTcLeadHistoryById(Long leadId);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tcLeadHistory 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TcLeadHistory> selectTcLeadHistoryList(TcLeadHistory tcLeadHistory);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tcLeadHistory 【请填写功能名称】
     * @return 结果
     */
    public int insertTcLeadHistory(TcLeadHistory tcLeadHistory);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tcLeadHistory 【请填写功能名称】
     * @return 结果
     */
    public int updateTcLeadHistory(TcLeadHistory tcLeadHistory);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param leadIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTcLeadHistoryByLeadIds(Long[] leadIds);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param leadId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTcLeadHistoryByLeadId(Long leadId);

    List<TcLeadHistory> getHistoryListByLeadId(Long leadId);

    boolean existsUser(Long userId, Long leadId);
}
