package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.project.business.domain.TcLeadHistory;
import com.ruoyi.project.business.service.ITcLeadHistoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-04-22
 */
@RestController
@RequestMapping("/system/leadHistory")
public class TcLeadHistoryController extends BaseController
{
    @Autowired
    private ITcLeadHistoryService tcLeadHistoryService;

    /**
     * 查询【请填写功能名称】列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TcLeadHistory tcLeadHistory)
    {
        startPage();
        List<TcLeadHistory> list = tcLeadHistoryService.selectTcLeadHistoryList(tcLeadHistory);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcLeadHistory tcLeadHistory)
    {
        List<TcLeadHistory> list = tcLeadHistoryService.selectTcLeadHistoryList(tcLeadHistory);
        ExcelUtil<TcLeadHistory> util = new ExcelUtil<TcLeadHistory>(TcLeadHistory.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcLeadHistoryService.selectTcLeadHistoryById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcLeadHistory tcLeadHistory)
    {
        return toAjax(tcLeadHistoryService.insertTcLeadHistory(tcLeadHistory));
    }

    /**
     * 修改【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcLeadHistory tcLeadHistory)
    {
        return toAjax(tcLeadHistoryService.updateTcLeadHistory(tcLeadHistory));
    }

    /**
     * 删除【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{leadIds}")
    public AjaxResult remove(@PathVariable Long[] leadIds)
    {
        return toAjax(tcLeadHistoryService.deleteTcLeadHistoryByLeadIds(leadIds));
    }

    /**
     * 根据 线索id 查询履历
     */
    @GetMapping("/getHistoryByLeadId/{leadId}")
    public AjaxResult getHistoryByLeadId(@PathVariable Long leadId) {
        return success(tcLeadHistoryService.getHistoryListByLeadId(leadId));
    }
}
